@@ -1,8 +1,8 @@
 /*
  * Copyright (C) 2000 Reinhard Müller <reinhard@src.gnome.org>
  * Copyright (C) 2000 - 2002 Rodrigo Moya <rodrigo@gnome-db.org>
- * Copyright (C) 2001 Carlos Perell Marn <carlos@gnome-db.org>
- * Copyright (C) 2001 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2001 Carlos Perelló Marín <carlos@gnome-db.org>
+ * Copyright (C) 2001 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2002 Gonzalo Paniagua Javier <gonzalo@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
@@ -46,7 +46,7 @@ struct VContext{
 
 struct ExecContext {
 	VContext   *current_vcontext;
-	GMutex     *mutex;
+	GRecMutex  *mutex;
 	GHashTable *hash; /* key = a GObject, value = a VContext where @context_object == key */
 };
 
@@ -71,7 +71,7 @@ struct VirtualFilteredData {
 	/* data */
 	GdaDataModel *model;
 	GdaDataModelIter *iter; /* not NULL while nrows == -1 */
-	GValueArray  *values;
+	GArray       *values_array;
 	gint          ncols;
 	gint          nrows; /* -1 until known */
 };
@@ -95,11 +95,11 @@ struct GdaVConnectionTableData {
 
 void                     _gda_vconnection_virtual_filtered_data_unref (VirtualFilteredData *data);
 
-void                     gda_vconnection_data_model_table_data_free (GdaVConnectionTableData *td);
+void                     _gda_vconnection_data_model_table_data_free (GdaVConnectionTableData *td);
 
-GdaVConnectionTableData *gda_vconnection_get_table_data_by_name (GdaVconnectionDataModel *cnc, const gchar *table_name);
-GdaVConnectionTableData *gda_vconnection_get_table_data_by_model (GdaVconnectionDataModel *cnc, GdaDataModel *model);
-GdaVConnectionTableData *gda_vconnection_get_table_data_by_unique_name (GdaVconnectionDataModel *cnc, const gchar *unique_name);
+GdaVConnectionTableData *_gda_vconnection_get_table_data_by_name (GdaVconnectionDataModel *cnc, const gchar *table_name);
+GdaVConnectionTableData *_gda_vconnection_get_table_data_by_model (GdaVconnectionDataModel *cnc, GdaDataModel *model);
+GdaVConnectionTableData *_gda_vconnection_get_table_data_by_unique_name (GdaVconnectionDataModel *cnc, const gchar *unique_name);
 
 void                     _gda_vconnection_set_working_obj (GdaVconnectionDataModel *cnc, GObject *obj);
 void                     _gda_vconnection_change_working_obj (GdaVconnectionDataModel *cnc, GObject *obj);
